<no title> — Rider 0.1.8a documentation

### Navigation

- index
- Rider 0.1.8a documentation »

Sphinx is a tool that makes it easy to create intelligent and beautiful documentation for Python projects (or other documents consisting of multiple reStructuredText sources), written by Georg Brandl. It was originally created for the new Python documentation, and has excellent facilities for Python project documentation, but C/C++ is supported as well, and more languages are planned.

Sphinx uses reStructuredText as its markup language, and many of its strengths come from the power and straightforwardness of reStructuredText and its parsing and translating suite, the Docutils.

Among its features are the following:

- Output formats: HTML (including derivative formats such as HTML Help, Epub and Qt Help), plain text, manual pages and LaTeX or direct PDF output using rst2pdf
- Extensive cross-references: semantic markup and automatic links for functions, classes, glossary terms and similar pieces of information
- Hierarchical structure: easy definition of a document tree, with automatic links to siblings, parents and children
- Automatic indices: general index as well as a module index
- Code handling: automatic highlighting using the Pygments highlighter
- Flexible HTML output using the Jinja 2 templating engine
- Various extensions are available, e.g. for automatic testing of snippets and inclusion of appropriately formatted docstrings
- Setuptools integration

### Navigation

- index
- Rider 0.1.8a documentation »